PyXMake Developer Guide: PyXMake.VTL.abaqus Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Functions | Variables
PyXMake.VTL.abaqus Namespace Reference

## Functions
def | main (BuildID, files="mcd_astandard", command=VTL.GetBuildCommand(6), libs='mcd_corex64', source=os.path.join(__mcd_core_path,"solver"), include=list(Utility.ArbitraryFlattening([[os.path.join(__mcd_core_path,"include", Utility.GetPlatform(), __arch)], [os.path.join(__mcd_core_path,"include", Utility.GetPlatform(), __arch, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, __arch)]])), dependency=os.path.join(__mcd_core_path,"lib", Utility.GetPlatform(), __arch), output=os.path.join(__mcd_core_path,"bin", Utility.GetPlatform(), __arch), scratch=VTL.Scratch, verbosity=1)

## Variables
| parser = argparse.ArgumentParser(description="Build a static Fortran library remotely on the institute cluster")
| metavar
| nargs
| help
| args
| make_opt = args.make[0]
string | BuildID = 'mcd_abaqus'

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile MCODAC for ABAQUS Standard & Explicit
                 on Windows. Can be combined with self-written code alike.
    Created on 25.06.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          -

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

def PyXMake.VTL.abaqus.main | ( |  | BuildID,
|  |  | files = `"mcd_astandard"`,
|  |  | command = `VTL.GetBuildCommand(6)`,
|  |  | libs = `'mcd_corex64'`,
|  |  | source = `os.path.join(__mcd_core_path,"solver")`,
|  |  | include = `list(Utility.ArbitraryFlattening([[os.path.join(__mcd_core_path,"include",Utility.GetPlatform(),__arch)], [os.path.join(__mcd_core_path,"include",Utility.GetPlatform(),__arch, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, __arch)]]))`,
|  |  | dependency = `os.path.join(__mcd_core_path,"lib",Utility.GetPlatform(),__arch)`,
|  |  | output = `os.path.join(__mcd_core_path,"bin",Utility.GetPlatform(),__arch)`,
|  |  | scratch = `VTL.Scratch`,
|  |  | verbosity = `1`
| ) |  |

    Main function to execute the script.

Definition at line 69 of file abaqus.py.